#!/bin/bash
#
# Script consists of Part 1 of the FDR job 
#  - Save "Server information"
#  - Save "Before FDR" logs
#  - INIT 
#  - METRICS 
#  - PERSIST_1 
#


#
# Configure Variable
#
if [ $# -ne 2 ]
then
	IOPS=280000

else
	IOPS=$1
fi

PERSIOPS=$(( $IOPS / 4 ))
INITIOPS=5000

HOME=/home/af150s3spc1v3/fdr;export HOME           # Absolute path of Home Template 
ROOT=/home/af150s3spc1v3;export ROOT       # Absolute path of Work Directories
SCRIPTS=/home/af150s3spc1v3/fdr/07_Execution;export SCRIPTS	# main script directory
TUNING=/home/af150s3spc1v3/fdr/06_Tunables;export TUNING

# benchmark and misc commands
GETHOSTINFO="./getHostInfo.sh"
EXPORTLOG=exportLog.exp;export EXPORTLOG


# create tmp directory for af150s3spc1v3 if it does not exist 
SPCTMP=/tmp/af150s3spc1v3;export SPCTMP
if [ ! -d ${SPCTMP} ]; then      
	mkdir ${SPCTMP}
fi

#
# Create confID
#
confID=AF150S3_20190917;export confID

# obtain jobID based on the timestamp
# jobID uniquely identifies the benchmark run
jobID=AL`date +%y%m%d%H%M%S`;export jobID
WORKDIR=${ROOT}/repository/${jobID};export WORKDIR # WORK Directory
#
cd $ROOT
mkdir repository 
mkdir $WORKDIR
for i in {117..117}
do
h=$(printf 'sv%d' "$i" )
ssh root@$h  "cd ${ROOT};mkdir repository;cd repository;mkdir ${jobID}"
done
#
# save Variables for Part 2 use
#
echo $HOME > ${SPCTMP}/HOME
echo $ROOT > ${SPCTMP}/ROOT
echo $SCRIPTS > ${SPCTMP}/SCRIPTS
echo $confID > ${SPCTMP}/lastconfID
echo $jobID > ${SPCTMP}/lastjobID
echo $WORKDIR > ${SPCTMP}/WORKDIR
echo $EXPORTLOG > ${SPCTMP}/EXPORTLOG
echo $PERSIOPS > ${SPCTMP}/PERSIOPS
echo $TUNING > ${SPCTMP}/TUNING
#
# setup the unique execution context(directory) for SPC1 job
#
# For Master host
# Copy the subdirectories to the new context 
cd $WORKDIR 
cp -r -p $HOME/*  .
echo -e AF150S3 "\n"  start time `date` "\n" | tee -a ${SPCTMP}/${jobID}_message.txt
echo -e  confID=$confID "\n" | tee -a ${SPCTMP}/${jobID}_message.txt
echo -e  jobID=$jobID "\n" | tee -a ${SPCTMP}/${jobID}_message.txt
echo "Starting AF150S3 FDR Job=${jobID}" | tee -a ${SPCTMP}/${jobID}_message.txt

# apply Linux tuning
for i in {116..117}
do
  h=$(printf 'sv%d' "$i" )
  ssh root@$h  "cd ${TUNING};./setupLinux.sh"
done
#
# Collect Server/HBA Information 
#
echo "Starting  Server/HBA Information  Collection Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt
cd $WORKDIR
cd 10_Reference_Info
# get Host Information from local and remote hosts
 for i in {116..117}
 do
  h=$(printf 'sv%d' "$i" )
  ssh root@${h} "cd ${WORKDIR};${HOME}/10_Reference_Info/getHostInfo.sh fdr_PRIMERGY_${jobID}-${h}"
  scp root@${h}:${WORKDIR}/*fdr_PRIMERGY_${jobID}-${h}*  .
 done
echo "Completed  Server/HBA Information  Collection Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt

#
# Collect Log
#
cd ..
echo "Starting  AF150S3 BeforeF log save Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt
# Save Before F log
${SCRIPTS}/${EXPORTLOG} ${jobID} BeforeF
echo "Completed AF150S3 BeforeF log save Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt

# Start Sequence of SPC1 benchmark jobs
#
cd ${WORKDIR}/09_Results
cp ${SCRIPTS}/SPC1_${confID}.asu .
cp ${SCRIPTS}/SPC1_${confID}.hst .
# create outuput directories in master and slave servers
for i in {116..117}
do
  h=$(printf 'sv%d' "$i" )
  ssh root@${h} "cd ${WORKDIR};mkdir output${h}"
done

echo "Starting  AF150S3 SPC1 sequence Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt
spc1 -master SPC1_${confID}.hst -run SPC1_INIT -iops ${INITIOPS} -storage SPC1_${confID}.asu 
spc1 -run SPC1_VERIFY -iops 100 -storage SPC1_${confID}.asu
spc1 -master SPC1_${confID}.hst -run SPC1_METRICS -iops ${IOPS} -storage SPC1_${confID}.asu
spc1 -run SPC1_VERIFY -iops 100 -storage SPC1_${confID}.asu
spc1 -master SPC1_${confID}.hst -run SPC1_PERSIST_1  -iops ${PERSIOPS} -storage SPC1_${confID}.asu

#
# Perform Power cycle
#
echo "Array is Ready for manual Power cycle Job=${jobID} at `date`" | tee -a ${SPCTMP}/${jobID}_message.txt
